@@ -6,12 +6,11 @@ from .common import (
     is_np_datetime_like,
     is_np_timedelta_like,
 )
-from .pycompat import dask_array_type
+from .pycompat import is_duck_dask_array
 
 
 def _season_from_months(months):
-    """Compute season (DJF, MAM, JJA, SON) from month ordinal
-    """
+    """Compute season (DJF, MAM, JJA, SON) from month ordinal"""
     # TODO: Move "season" accessor upstream into pandas
     seasons = np.array(["DJF", "MAM", "JJA", "SON"])
     months = np.asarray(months)
@@ -70,7 +69,7 @@ def _get_date_field(values, name, dtype):
     else:
         access_method = _access_through_cftimeindex
 
-    if isinstance(values, dask_array_type):
+    if is_duck_dask_array(values):
         from dask.array import map_blocks
 
         return map_blocks(access_method, values, name, dtype=dtype)
@@ -104,9 +103,10 @@ def _round_field(values, name, freq):
     ----------
     values : np.ndarray or dask.array-like
         Array-like container of datetime-like values
-    name : str (ceil, floor, round)
+    name : {"ceil", "floor", "round"}
         Name of rounding function
-    freq : a freq string indicating the rounding resolution
+    freq : str
+        a freq string indicating the rounding resolution
 
     Returns
     -------
@@ -114,7 +114,7 @@ def _round_field(values, name, freq):
         Array-like of datetime fields accessed for each element in values
 
     """
-    if isinstance(values, dask_array_type):
+    if is_duck_dask_array(values):
         from dask.array import map_blocks
 
         dtype = np.datetime64 if is_np_datetime_like(values.dtype) else np.dtype("O")
@@ -151,7 +151,7 @@ def _strftime(values, date_format):
         access_method = _strftime_through_series
     else:
         access_method = _strftime_through_cftimeindex
-    if isinstance(values, dask_array_type):
+    if is_duck_dask_array(values):
         from dask.array import map_blocks
 
         return map_blocks(access_method, values, date_format)
@@ -190,8 +190,8 @@ class Properties:
 
         Parameters
         ----------
-        freq : a freq string indicating the rounding resolution
-            e.g. 'D' for daily resolution
+        freq : str
+            a freq string indicating the rounding resolution e.g. "D" for daily resolution
 
         Returns
         -------
@@ -207,8 +207,8 @@ class Properties:
 
         Parameters
         ----------
-        freq : a freq string indicating the rounding resolution
-            e.g. 'D' for daily resolution
+        freq : str
+            a freq string indicating the rounding resolution e.g. "D" for daily resolution
 
         Returns
         -------
@@ -223,8 +223,8 @@ class Properties:
 
         Parameters
         ----------
-        freq : a freq string indicating the rounding resolution
-            e.g. 'D' for daily resolution
+        freq : str
+            a freq string indicating the rounding resolution e.g. "D" for daily resolution
 
         Returns
         -------
@@ -249,30 +249,30 @@ class DatetimeAccessor(Properties):
     >>> ts
     <xarray.DataArray (time: 10)>
     array(['2000-01-01T00:00:00.000000000', '2000-01-02T00:00:00.000000000',
-        '2000-01-03T00:00:00.000000000', '2000-01-04T00:00:00.000000000',
-        '2000-01-05T00:00:00.000000000', '2000-01-06T00:00:00.000000000',
-        '2000-01-07T00:00:00.000000000', '2000-01-08T00:00:00.000000000',
-        '2000-01-09T00:00:00.000000000', '2000-01-10T00:00:00.000000000'],
-        dtype='datetime64[ns]')
+           '2000-01-03T00:00:00.000000000', '2000-01-04T00:00:00.000000000',
+           '2000-01-05T00:00:00.000000000', '2000-01-06T00:00:00.000000000',
+           '2000-01-07T00:00:00.000000000', '2000-01-08T00:00:00.000000000',
+           '2000-01-09T00:00:00.000000000', '2000-01-10T00:00:00.000000000'],
+          dtype='datetime64[ns]')
     Coordinates:
-    * time     (time) datetime64[ns] 2000-01-01 2000-01-02 ... 2000-01-10
-    >>> ts.dt
-    <xarray.core.accessor_dt.DatetimeAccessor object at 0x118b54d68>
+      * time     (time) datetime64[ns] 2000-01-01 2000-01-02 ... 2000-01-10
+    >>> ts.dt  # doctest: +ELLIPSIS
+    <xarray.core.accessor_dt.DatetimeAccessor object at 0x...>
     >>> ts.dt.dayofyear
     <xarray.DataArray 'dayofyear' (time: 10)>
     array([ 1,  2,  3,  4,  5,  6,  7,  8,  9, 10])
     Coordinates:
-    * time     (time) datetime64[ns] 2000-01-01 2000-01-02 ... 2000-01-10
+      * time     (time) datetime64[ns] 2000-01-01 2000-01-02 ... 2000-01-10
     >>> ts.dt.quarter
     <xarray.DataArray 'quarter' (time: 10)>
     array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1])
     Coordinates:
-    * time     (time) datetime64[ns] 2000-01-01 2000-01-02 ... 2000-01-10
+      * time     (time) datetime64[ns] 2000-01-01 2000-01-02 ... 2000-01-10
 
     """
 
     def strftime(self, date_format):
-        '''
+        """
         Return an array of formatted strings specified by date_format, which
         supports the same string format as the python standard library. Details
         of the string format can be found in `python string format doc
@@ -290,13 +290,12 @@ class DatetimeAccessor(Properties):
 
         Examples
         --------
+        >>> import datetime
         >>> rng = xr.Dataset({"time": datetime.datetime(2000, 1, 1)})
         >>> rng["time"].dt.strftime("%B %d, %Y, %r")
         <xarray.DataArray 'strftime' ()>
         array('January 01, 2000, 12:00:00 AM', dtype=object)
         """
-
-        '''
         obj_type = type(self._obj)
 
         result = _strftime(self._obj.data, date_format)
@@ -398,32 +397,32 @@ class TimedeltaAccessor(Properties):
     >>> ts
     <xarray.DataArray (time: 20)>
     array([ 86400000000000, 108000000000000, 129600000000000, 151200000000000,
-        172800000000000, 194400000000000, 216000000000000, 237600000000000,
-        259200000000000, 280800000000000, 302400000000000, 324000000000000,
-        345600000000000, 367200000000000, 388800000000000, 410400000000000,
-        432000000000000, 453600000000000, 475200000000000, 496800000000000],
-        dtype='timedelta64[ns]')
+           172800000000000, 194400000000000, 216000000000000, 237600000000000,
+           259200000000000, 280800000000000, 302400000000000, 324000000000000,
+           345600000000000, 367200000000000, 388800000000000, 410400000000000,
+           432000000000000, 453600000000000, 475200000000000, 496800000000000],
+          dtype='timedelta64[ns]')
     Coordinates:
-    * time     (time) timedelta64[ns] 1 days 00:00:00 ... 5 days 18:00:00
-    >>> ts.dt
-    <xarray.core.accessor_dt.TimedeltaAccessor object at 0x109a27d68>
+      * time     (time) timedelta64[ns] 1 days 00:00:00 ... 5 days 18:00:00
+    >>> ts.dt  # doctest: +ELLIPSIS
+    <xarray.core.accessor_dt.TimedeltaAccessor object at 0x...>
     >>> ts.dt.days
     <xarray.DataArray 'days' (time: 20)>
     array([1, 1, 1, 1, 2, 2, 2, 2, 3, 3, 3, 3, 4, 4, 4, 4, 5, 5, 5, 5])
     Coordinates:
-    * time     (time) timedelta64[ns] 1 days 00:00:00 ... 5 days 18:00:00
+      * time     (time) timedelta64[ns] 1 days 00:00:00 ... 5 days 18:00:00
     >>> ts.dt.microseconds
     <xarray.DataArray 'microseconds' (time: 20)>
     array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0])
     Coordinates:
-    * time     (time) timedelta64[ns] 1 days 00:00:00 ... 5 days 18:00:00
+      * time     (time) timedelta64[ns] 1 days 00:00:00 ... 5 days 18:00:00
     >>> ts.dt.seconds
     <xarray.DataArray 'seconds' (time: 20)>
     array([    0, 21600, 43200, 64800,     0, 21600, 43200, 64800,     0,
-        21600, 43200, 64800,     0, 21600, 43200, 64800,     0, 21600,
-        43200, 64800])
+           21600, 43200, 64800,     0, 21600, 43200, 64800,     0, 21600,
+           43200, 64800])
     Coordinates:
-    * time     (time) timedelta64[ns] 1 days 00:00:00 ... 5 days 18:00:00
+      * time     (time) timedelta64[ns] 1 days 00:00:00 ... 5 days 18:00:00
     """
 
     days = Properties._tslib_field_accessor(
