@@ -43,7 +43,7 @@ def unique_value_groups(ar, sort=True):
     ----------
     ar : array-like
         Input array. This will be flattened if it is not already 1-D.
-    sort : boolean, optional
+    sort : bool, optional
         Whether or not to sort unique values.
 
     Returns
@@ -64,8 +64,8 @@ def unique_value_groups(ar, sort=True):
 
 
 def _dummy_copy(xarray_obj):
-    from .dataset import Dataset
     from .dataarray import DataArray
+    from .dataset import Dataset
 
     if isinstance(xarray_obj, Dataset):
         res = Dataset(
@@ -102,8 +102,7 @@ def _is_one_or_none(obj):
 
 
 def _consolidate_slices(slices):
-    """Consolidate adjacent slices in a list of slices.
-    """
+    """Consolidate adjacent slices in a list of slices."""
     result = []
     last_slice = slice(None)
     for slice_ in slices:
@@ -128,7 +127,7 @@ def _inverse_permutation_indices(positions):
 
     Parameters
     ----------
-    positions : list of np.ndarray or slice objects.
+    positions : list of ndarray or slice
         If slice objects, all are assumed to be slices.
 
     Returns
@@ -283,16 +282,16 @@ class GroupBy(SupportsArithmetic):
             Object to group.
         group : DataArray
             Array with the group values.
-        squeeze : boolean, optional
+        squeeze : bool, optional
             If "group" is a coordinate of object, `squeeze` controls whether
             the subarrays have a dimension of length 1 along that coordinate or
             if the dimension is squeezed out.
-        grouper : pd.Grouper, optional
+        grouper : pandas.Grouper, optional
             Used for grouping values along the `group` array.
         bins : array-like, optional
             If `bins` is specified, the groups will be discretized into the
             specified bins by `pandas.cut`.
-        restore_coord_dims : bool, default True
+        restore_coord_dims : bool, default: True
             If True, also restore the dimension order of multi-dimensional
             coordinates.
         cut_kwargs : dict, optional
@@ -310,7 +309,8 @@ class GroupBy(SupportsArithmetic):
             if not hashable(group):
                 raise TypeError(
                     "`group` must be an xarray.DataArray or the "
-                    "name of an xarray variable or dimension"
+                    "name of an xarray variable or dimension."
+                    f"Received {group!r} instead."
                 )
             group = obj[group]
             if len(group) == 0:
@@ -532,8 +532,10 @@ class GroupBy(SupportsArithmetic):
 
         Parameters
         ----------
-        value : valid type for the grouped object's fillna method
-            Used to fill all matching missing values by group.
+        value
+            Used to fill all matching missing values by group. Needs
+            to be of a valid type for the wrapped object's fillna
+            method.
 
         Returns
         -------
@@ -555,13 +557,13 @@ class GroupBy(SupportsArithmetic):
 
         Parameters
         ----------
-        q : float in range of [0,1] (or sequence of floats)
+        q : float or sequence of float
             Quantile to compute, which must be between 0 and 1
             inclusive.
-        dim : `...`, str or sequence of str, optional
+        dim : ..., str or sequence of str, optional
             Dimension(s) over which to apply quantile.
             Defaults to the grouped dimension.
-        interpolation : {'linear', 'lower', 'higher', 'midpoint', 'nearest'}
+        interpolation : {"linear", "lower", "higher", "midpoint", "nearest"}, default: "linear"
             This optional parameter specifies the interpolation method to
             use when the desired quantile lies between two data points
             ``i < j``:
@@ -597,7 +599,7 @@ class GroupBy(SupportsArithmetic):
         >>> da = xr.DataArray(
         ...     [[1.3, 8.4, 0.7, 6.9], [0.7, 4.2, 9.4, 1.5], [6.5, 7.3, 2.6, 1.9]],
         ...     coords={"x": [0, 0, 1], "y": [1, 1, 2, 2]},
-        ...     dims=("y", "y"),
+        ...     dims=("x", "y"),
         ... )
         >>> ds = xr.Dataset({"a": da})
         >>> da.groupby("x").quantile(0)
@@ -605,8 +607,8 @@ class GroupBy(SupportsArithmetic):
         array([[0.7, 4.2, 0.7, 1.5],
                [6.5, 7.3, 2.6, 1.9]])
         Coordinates:
-            quantile  float64 0.0
           * y         (y) int64 1 1 2 2
+            quantile  float64 0.0
           * x         (x) int64 0 1
         >>> ds.groupby("y").quantile(0, dim=...)
         <xarray.Dataset>
@@ -622,6 +624,7 @@ class GroupBy(SupportsArithmetic):
                 [4.2 , 6.3 , 8.4 ],
                 [0.7 , 5.05, 9.4 ],
                 [1.5 , 4.2 , 6.9 ]],
+        <BLANKLINE>
                [[6.5 , 6.5 , 6.5 ],
                 [7.3 , 7.3 , 7.3 ],
                 [2.6 , 2.6 , 2.6 ],
@@ -659,8 +662,8 @@ class GroupBy(SupportsArithmetic):
 
         Parameters
         ----------
-        cond : DataArray or Dataset with boolean dtype
-            Locations at which to preserve this objects values.
+        cond : DataArray or Dataset
+            Locations at which to preserve this objects values. dtypes have to be `bool`
         other : scalar, DataArray or Dataset, optional
             Value to use for locations in this object where ``cond`` is False.
             By default, inserts missing values.
@@ -685,13 +688,11 @@ class GroupBy(SupportsArithmetic):
         return self.reduce(op, self._group_dim, skipna=skipna, keep_attrs=keep_attrs)
 
     def first(self, skipna=None, keep_attrs=None):
-        """Return the first element of each group along the group dimension
-        """
+        """Return the first element of each group along the group dimension"""
         return self._first_or_last(duck_array_ops.first, skipna, keep_attrs)
 
     def last(self, skipna=None, keep_attrs=None):
-        """Return the last element of each group along the group dimension
-        """
+        """Return the last element of each group along the group dimension"""
         return self._first_or_last(duck_array_ops.last, skipna, keep_attrs)
 
     def assign_coords(self, coords=None, **coords_kwargs):
@@ -716,8 +717,7 @@ def _maybe_reorder(xarray_obj, dim, positions):
 
 
 class DataArrayGroupBy(GroupBy, ImplementsArrayReduce):
-    """GroupBy object specialized to grouping DataArray objects
-    """
+    """GroupBy object specialized to grouping DataArray objects"""
 
     def _iter_grouped_shortcut(self):
         """Fast version of `_iter_grouped` that yields Variables without
@@ -768,7 +768,7 @@ class DataArrayGroupBy(GroupBy, ImplementsArrayReduce):
 
         Parameters
         ----------
-        func : function
+        func : callable
             Callable to apply to each array.
         shortcut : bool, optional
             Whether or not to shortcut evaluation under the assumptions that:
@@ -782,9 +782,9 @@ class DataArrayGroupBy(GroupBy, ImplementsArrayReduce):
             If these conditions are satisfied `shortcut` provides significant
             speedup. This should be the case for many common groupby operations
             (e.g., applying numpy ufuncs).
-        ``*args`` : tuple, optional
+        *args : tuple, optional
             Positional arguments passed to `func`.
-        ``**kwargs``
+        **kwargs
             Used to call `func(ar, **kwargs)` for each array `ar`.
 
         Returns
@@ -846,11 +846,11 @@ class DataArrayGroupBy(GroupBy, ImplementsArrayReduce):
 
         Parameters
         ----------
-        func : function
+        func : callable
             Function which can be called in the form
             `func(x, axis=axis, **kwargs)` to return the result of collapsing
             an np.ndarray over an integer valued axis.
-        dim : `...`, str or sequence of str, optional
+        dim : ..., str or sequence of str, optional
             Dimension(s) over which to apply `func`.
         axis : int or sequence of int, optional
             Axis(es) over which to apply `func`. Only one of the 'dimension'
@@ -906,7 +906,7 @@ class DatasetGroupBy(GroupBy, ImplementsDatasetReduce):
 
         Parameters
         ----------
-        func : function
+        func : callable
             Callable to apply to each sub-dataset.
         args : tuple, optional
             Positional arguments to pass to `func`.
@@ -957,11 +957,11 @@ class DatasetGroupBy(GroupBy, ImplementsDatasetReduce):
 
         Parameters
         ----------
-        func : function
+        func : callable
             Function which can be called in the form
             `func(x, axis=axis, **kwargs)` to return the result of collapsing
             an np.ndarray over an integer valued axis.
-        dim : `...`, str or sequence of str, optional
+        dim : ..., str or sequence of str, optional
             Dimension(s) over which to apply `func`.
         axis : int or sequence of int, optional
             Axis(es) over which to apply `func`. Only one of the 'dimension'
