@@ -1,8 +1,8 @@
 try:
     import dask
     import dask.array
+    from dask.array.utils import meta_from_array
     from dask.highlevelgraph import HighLevelGraph
-    from .dask_array_compat import meta_from_array
 
 except ImportError:
     pass
@@ -123,8 +123,7 @@ def make_meta(obj):
 def infer_template(
     func: Callable[..., T_DSorDA], obj: Union[DataArray, Dataset], *args, **kwargs
 ) -> T_DSorDA:
-    """Infer return object by running the function on meta objects.
-    """
+    """Infer return object by running the function on meta objects."""
     meta_args = [make_meta(arg) for arg in (obj,) + args]
 
     try:
@@ -175,7 +174,7 @@ def map_blocks(
 
     Parameters
     ----------
-    func: callable
+    func : callable
         User-provided function that accepts a DataArray or Dataset as its first
         parameter ``obj``. The function will receive a subset or 'block' of ``obj`` (see below),
         corresponding to one chunk along each chunked dimension. ``func`` will be
@@ -185,15 +184,15 @@ def map_blocks(
 
         This function cannot add a new chunked dimension.
 
-    obj: DataArray, Dataset
+    obj : DataArray, Dataset
         Passed to the function as its first argument, one block at a time.
-    args: Sequence
+    args : sequence
         Passed to func after unpacking and subsetting any xarray objects by blocks.
         xarray objects in args must be aligned with obj, otherwise an error is raised.
-    kwargs: Mapping
+    kwargs : mapping
         Passed verbatim to func after unpacking. xarray objects, if any, will not be
         subset to blocks. Passing dask collections in kwargs is not allowed.
-    template: (optional) DataArray, Dataset
+    template : DataArray or Dataset, optional
         xarray object representing the final result after compute is called. If not provided,
         the function will be first run on mocked-up data, that looks like ``obj`` but
         has sizes 0, to determine properties of the returned object such as dtype,
@@ -234,11 +233,14 @@ def map_blocks(
     ...     clim = gb.mean(dim="time")
     ...     return gb - clim
     >>> time = xr.cftime_range("1990-01", "1992-01", freq="M")
+    >>> month = xr.DataArray(time.month, coords={"time": time}, dims=["time"])
     >>> np.random.seed(123)
     >>> array = xr.DataArray(
-    ...     np.random.rand(len(time)), dims="time", coords=[time]
+    ...     np.random.rand(len(time)),
+    ...     dims=["time"],
+    ...     coords={"time": time, "month": month},
     ... ).chunk()
-    >>> xr.map_blocks(calculate_anomaly, array, template=array).compute()
+    >>> array.map_blocks(calculate_anomaly, template=array).compute()
     <xarray.DataArray (time: 24)>
     array([ 0.12894847,  0.11323072, -0.0855964 , -0.09334032,  0.26848862,
             0.12382735,  0.22460641,  0.07650108, -0.07673453, -0.22865714,
@@ -247,24 +249,19 @@ def map_blocks(
             0.07673453,  0.22865714,  0.19063865, -0.0590131 ])
     Coordinates:
       * time     (time) object 1990-01-31 00:00:00 ... 1991-12-31 00:00:00
+        month    (time) int64 1 2 3 4 5 6 7 8 9 10 11 12 1 2 3 4 5 6 7 8 9 10 11 12
 
     Note that one must explicitly use ``args=[]`` and ``kwargs={}`` to pass arguments
     to the function being applied in ``xr.map_blocks()``:
 
-    >>> xr.map_blocks(
-    ...     calculate_anomaly,
-    ...     array,
-    ...     kwargs={"groupby_type": "time.year"},
-    ...     template=array,
-    ... )
+    >>> array.map_blocks(
+    ...     calculate_anomaly, kwargs={"groupby_type": "time.year"}, template=array,
+    ... )  # doctest: +ELLIPSIS
     <xarray.DataArray (time: 24)>
-    array([ 0.15361741, -0.25671244, -0.31600032,  0.008463  ,  0.1766172 ,
-           -0.11974531,  0.43791243,  0.14197797, -0.06191987, -0.15073425,
-           -0.19967375,  0.18619794, -0.05100474, -0.42989909, -0.09153273,
-            0.24841842, -0.30708526, -0.31412523,  0.04197439,  0.0422506 ,
-            0.14482397,  0.35985481,  0.23487834,  0.12144652])
+    dask.array<calculate_anomaly-...-<this, shape=(24,), dtype=float64, chunksize=(24,), chunktype=numpy.ndarray>
     Coordinates:
-        * time     (time) object 1990-01-31 00:00:00 ... 1991-12-31 00:00:00
+      * time     (time) object 1990-01-31 00:00:00 ... 1991-12-31 00:00:00
+        month    (time) int64 dask.array<chunksize=(24,), meta=np.ndarray>
     """
 
     def _wrapper(
