@@ -1,7 +1,7 @@
 import numpy as np
 
 from .pdcompat import count_not_none
-from .pycompat import dask_array_type
+from .pycompat import is_duck_dask_array
 
 
 def _get_alpha(com=None, span=None, halflife=None, alpha=None):
@@ -13,8 +13,8 @@ def _get_alpha(com=None, span=None, halflife=None, alpha=None):
 
 
 def move_exp_nanmean(array, *, axis, alpha):
-    if isinstance(array, dask_array_type):
-        raise TypeError("rolling_exp is not currently support for dask arrays")
+    if is_duck_dask_array(array):
+        raise TypeError("rolling_exp is not currently support for dask-like arrays")
     import numbagg
 
     if axis == ():
@@ -65,17 +65,13 @@ class RollingExp:
     ----------
     obj : Dataset or DataArray
         Object to window.
-    windows : A single mapping from a single dimension name to window value
-        dim : str
-            Name of the dimension to create the rolling exponential window
-            along (e.g., `time`).
-        window : int
-            Size of the moving window. The type of this is specified in
-            `window_type`
-    window_type : str, one of ['span', 'com', 'halflife', 'alpha'], default 'span'
+    windows : mapping of hashable to int
+        A mapping from the name of the dimension to create the rolling
+        exponential window along (e.g. `time`) to the size of the moving window.
+    window_type : {"span", "com", "halflife", "alpha"}, default: "span"
         The format of the previously supplied window. Each is a simple
         numerical transformation of the others. Described in detail:
-        https://pandas.pydata.org/pandas-docs/stable/generated/pandas.DataFrame.ewm.html
+        https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.DataFrame.ewm.html
 
     Returns
     -------
@@ -97,7 +93,7 @@ class RollingExp:
         >>> da = xr.DataArray([1, 1, 2, 2, 2], dims="x")
         >>> da.rolling_exp(x=2, window_type="span").mean()
         <xarray.DataArray (x: 5)>
-        array([1.      , 1.      , 1.692308, 1.9     , 1.966942])
+        array([1.        , 1.        , 1.69230769, 1.9       , 1.96694215])
         Dimensions without coordinates: x
         """
 
