@@ -291,6 +291,12 @@ def _determine_cmap_params(
         cmap, newnorm = _build_discrete_cmap(cmap, levels, extend, filled)
         norm = newnorm if norm is None else norm
 
+    # vmin & vmax needs to be None if norm is passed
+    # TODO: always return a norm with vmin and vmax
+    if norm is not None:
+        vmin = None
+        vmax = None
+
     return dict(
         vmin=vmin, vmax=vmax, cmap=cmap, extend=extend, levels=levels, norm=norm
     )
@@ -395,7 +401,7 @@ def _assert_valid_xy(darray, xy, name):
     """
 
     # MultiIndex cannot be plotted; no point in allowing them here
-    multiindex = set([darray._level_coords[lc] for lc in darray._level_coords])
+    multiindex = {darray._level_coords[lc] for lc in darray._level_coords}
 
     valid_xy = (
         set(darray.dims) | set(darray.coords) | set(darray._level_coords)
@@ -440,8 +446,8 @@ def get_axis(figsize=None, size=None, aspect=None, ax=None, **kwargs):
 
 
 def label_from_attrs(da, extra=""):
-    """ Makes informative labels if variable metadata (attrs) follows
-        CF conventions. """
+    """Makes informative labels if variable metadata (attrs) follows
+    CF conventions."""
 
     if da.attrs.get("long_name"):
         name = da.attrs["long_name"]
@@ -620,6 +626,10 @@ def _add_colorbar(primitive, ax, cbar_ax, cbar_kwargs, cmap_params):
     else:
         cbar_kwargs.setdefault("cax", cbar_ax)
 
+    # dont pass extend as kwarg if it is in the mappable
+    if hasattr(primitive, "extend"):
+        cbar_kwargs.pop("extend")
+
     fig = ax.get_figure()
     cbar = fig.colorbar(primitive, **cbar_kwargs)
 
